@@ -52,5 +52,5 @@ G.inputs.y = F2.outputs.Aval
 
 w = pyutilib.workflow.Workflow()
 w.add(G)
-print w(a='a', aval=1, A='A', Aval=2)
+print(w(a='a', aval=1, A='A', Aval=2))
 # @:ex
