@@ -10,15 +10,15 @@
 import pyutilib.component.core
 pyutilib.component.core.PluginGlobals.push_env("pyutilib.workflow")
 
-from globals import *
-from connector import *
-from port import *
-from resource import *
-from task import *
-from workflow import *
-from file import *
-from executable import *
-from tasks import *
-from driver import *
+from pyutilib.workflow.globals import *
+from pyutilib.workflow.connector import *
+from pyutilib.workflow.port import *
+from pyutilib.workflow.resource import *
+from pyutilib.workflow.task import *
+from pyutilib.workflow.workflow import *
+from pyutilib.workflow.file import *
+from pyutilib.workflow.executable import *
+from pyutilib.workflow.tasks import *
+from pyutilib.workflow.driver import *
 
 pyutilib.component.core.PluginGlobals.pop_env()
